ifermi package
==============

ifermi.analysis module
-----------------------

.. automodule:: ifermi.analysis
   :members:
   :undoc-members:
   :show-inheritance:

ifermi.brillouin\_zone module
-----------------------------

.. automodule:: ifermi.brillouin_zone
   :members:
   :show-inheritance:

ifermi.interpolate module
--------------------------

.. automodule:: ifermi.interpolate
   :members:
   :undoc-members:
   :show-inheritance:

ifermi.kpoints module
---------------------

.. automodule:: ifermi.kpoints
   :members:
   :undoc-members:
   :show-inheritance:

ifermi.plot module
---------------------

.. automodule:: ifermi.plot
   :members:
   :undoc-members:
   :show-inheritance:

ifermi.slice module
-------------------

.. automodule:: ifermi.slice
   :members:
   :show-inheritance:

ifermi.surface module
---------------------

.. automodule:: ifermi.surface
   :members:
   :show-inheritance:
